@@ -381,20 +381,18 @@ class Misc(callbacks.Plugin):
                 return
         try:
             L = irc._mores[userHostmask]
-            number = self.registryValue('mores', msg.channel, irc.network)
-            chunks = [L.pop() for x in range(0, number)]
-            if L:
-                if len(L) < 2:
-                    more = _('1 more message')
-                else:
-                    more = _('%i more messages') % len(L)
-                chunks[-1] += format(' \x02(%s)\x0F', more)
-            irc.replies(chunks, noLengthCheck=True, oneToOne=False)
         except KeyError:
             irc.error(_('You haven\'t asked me a command; perhaps you want '
                       'to see someone else\'s more.  To do so, call this '
-                      'command with that person\'s nick.'))
-        except IndexError:
+                      'command with that person\'s nick.'), Raise=True)
+        number = self.registryValue('mores', msg.channel, irc.network)
+        msgs = L[-number:]
+        msgs.reverse()
+        L[-number:] = []
+        if msgs:
+            for msg in msgs:
+                irc.queueMsg(msg)
+        else:
             irc.error(_('That\'s all, there is no more.'))
     more = wrap(more, [additional('seenNick')])
 
